Changelog
=========

0.1.4 (2023-02-12)
------------------
- General package setup updates.

0.1.3 (2023-02-12)
------------------
- General updates for LogManager, ArgsManages.
- Add Executable class.
- Add checkout, pull methods in Git class.

0.1.2 (2023-02-01)
------------------
- Add ADict class.
- Add Git and git.FileStatus class.

0.1.1 (2022-10-02)
------------------
- Add context_cwd to Path submodule.

0.1.0 (2022-09-22)
------------------
- Initial commit.
